pub unsafe extern "C" fn rcl_timer_get_guard_condition(
timer: *const rcl_timer_t
) -> *mut rcl_guard_condition_tExpand description
Retrieve a guard condition used by the timer to wake the waitset when using ROSTime.
pub unsafe extern "C" fn rcl_timer_get_guard_condition(
timer: *const rcl_timer_t
) -> *mut rcl_guard_condition_tRetrieve a guard condition used by the timer to wake the waitset when using ROSTime.